@@ -10,5 +10,5 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-__version__ = "0.0.1"
-__author__ = "@joocer"
+__version__: str = "0.0.21"
+__author__: str = "@joocer"
